import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { ComputeType } from '@project-lakechain/core/compute-type';
import { OllamaEmbeddingModel } from './definitions/model';
import { InfrastructureDefinition } from './definitions/infrastructure';
import { OllamaEmbeddingProcessorProps } from './definitions/opts';
import { Middleware, MiddlewareBuilder } from '@project-lakechain/core/middleware';
/**
 * The builder class for the `OllamaEmbeddingProcessor` service.
 */
declare class OllamaEmbeddingProcessorBuilder extends MiddlewareBuilder {
    private providerProps;
    /**
     * Sets the Ollama embedding model to use.
     * @param model the identifier of the Ollama embedding model to use.
     * @see https://ollama.com/library
     * @returns the builder instance.
     */
    withModel(model: OllamaEmbeddingModel): this;
    /**
     * Sets the infrastructure to use to run the ollama model.
     * @param instanceType the instance type to use.
     * @returns the builder instance.
     */
    withInfrastructure(infrastructure: InfrastructureDefinition): this;
    /**
     * @returns a new instance of the `OllamaEmbeddingProcessor`
     * service constructed with the given parameters.
     */
    build(): OllamaEmbeddingProcessor;
}
/**
 * A service allowing to embed documents using
 * embedding models supported by Ollama.
 */
export declare class OllamaEmbeddingProcessor extends Middleware {
    private props;
    /**
     * The builder for the `OllamaEmbeddingProcessor` service.
     */
    static readonly Builder: typeof OllamaEmbeddingProcessorBuilder;
    /**
     * Construct constructor.
     */
    constructor(scope: Construct, id: string, props: OllamaEmbeddingProcessorProps);
    /**
     * Allows a grantee to read from the processed documents
     * generated by this middleware.
     */
    grantReadProcessedDocuments(grantee: iam.IGrantable): iam.Grant;
    /**
     * @returns an array of mime-types supported as input
     * type by this middleware.
     */
    supportedInputTypes(): string[];
    /**
     * @returns an array of mime-types supported as output
     * type by the data producer.
     */
    supportedOutputTypes(): string[];
    /**
     * @returns the supported compute types by a given
     * middleware.
     */
    supportedComputeTypes(): ComputeType[];
    /**
     * @returns the middleware conditional statement defining
     * in which conditions this middleware should be executed.
     * In this case, we want the middleware to only be invoked
     * when the document mime-type is supported, and the event
     * type is `document-created`.
     */
    conditional(): import("@project-lakechain/core/dsl/vocabulary/conditions").ConditionalStatement;
}
export { OllamaEmbeddingModel } from './definitions/model';
export { InfrastructureDefinition } from './definitions/infrastructure';
